pub struct HoprUnacknowledgedTicketProcessorConfig {
pub unack_ticket_timeout: Duration,
pub max_unack_tickets: usize,
pub use_batch_verification: bool,
}Expand description
Configuration for the HoprUnacknowledgedTicketProcessor.
Fields
unack_ticket_timeout: DurationTime after which an unacknowledged ticket is considered stale and is removed from the cache.
If the counterparty does not send an acknowledgement within this period, the ticket is lost forever.
Default is 30 seconds.
max_unack_tickets: usizeMaximum number of unacknowledged tickets that can be stored in the cache at any given time.
When more tickets are received, the oldest ones are discarded and lost forever.
Default is 10 000 000.
use_batch_verification: boolIndicates whether to use batch verification algorithm for acknowledgements.
This has a positive performance impact on higher workloads.
Default is true.